@@ -35,7 +35,7 @@ class ftpUtil:
             # 根据文件大小fsize和时间duration，在数据库中判断是否已采集(>0)，是的话就返回，否则继续
             iexist=self.__mutil.sftp_file_repeat(fdesc,fsize,duration)
             if iexist>0:
-                print("已采集过：%s" % fdesc)
+                print("repeat：%s,%d,%f" % (fdesc,fsize,duration))
                 return
             transport = paramiko.Transport((self.__hostname, self.__host_port))
             transport.connect(username=self.__username_stud, password=self.__password_stud)
@@ -51,11 +51,11 @@ class ftpUtil:
             no = no_file.zfill(8)
             remote_file = pid + "_" + stud + "_" + no + ftype
             sftp.put(local_path, remote_file)
-            print('上传成功......')
+            print('success upload......')
             sftp.close()
             transport.close()
         except Exception as ex:
-            print("连接出现如下异常%s" % ex)
+            print("connect error:%s" % ex)
 
         try:
             # 记录文件列表
@@ -71,7 +71,7 @@ class ftpUtil:
                                        duration,
                                        ftype,pid)
         except Exception as ex:
-            print("日志记录出现如下异常%s" % ex)
+            print("sftp_file_ins error:%s" % ex)
 
     def putfile_stud(self,local_path,prj_id,stud_id,no_file):
         self.putfile_project(local_path,prj_id,stud_id,no_file,'');
