@@ -98,7 +98,7 @@ class mysqlUtil:
             df.to_sql("sftp_files", self.engine, if_exists='append', index=False)  # 'sftp_files'
 
         except Exception as ex:
-            print("日志记录出现如下异常%s" % ex)
+            print("sftp_file_ins error:%s" % ex)
 
     # 获了上传文件记录
     def get_file_list(self, ftype):
